@@ -5,7 +5,7 @@
  * @package Fishers_Theme
  */
 
-$feat_image = get_field('featured_image');
+$feat_image = get_field('feat_image');
 
 ?>
 
@@ -14,11 +14,11 @@ $feat_image = get_field('featured_image');
         <div class="row">
             <div class="col-12 col-md-5">
                 <?php if ($feat_image) {
-                    echo Blue2\Scruffy\Utils::acf_img($image, [
+                    echo Blue2\Scruffy\Utils::acf_img($feat_image, [
                         'class' => 'p-archive__image'
                     ]);
                 } else {
-                    echo '<img class="p-archive__image" src="https://via.placeholder.com/448x253?text=thumb" width="448" height="253" alt="" loading="lazy">';
+                    echo '<img class="p-archive__image" src="' . get_template_directory_uri() . '/dist/images/news-placeholder.png" width="460" height="318" alt="" loading="lazy">';
                 } ?>
             </div>
             <div class="col-12 col-md-7 flow flex-column">
